Afrikaans
Akan
Albanian
Amharic
Arabic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
Dutch
English
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
French
Frisian
Ga
Galician
Georgian
German
Greek
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranî)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Brazil)
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish
Spanish (Latin American)
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Thai
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkish
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
Previously on "The Valley"...
Let's play Truth or Dare.
Have you ever gotten it up the butt?
-[music warps down] -[laughter]
No, Janet!
It's your guys' trip, but, like, being in one home
with my ex-husband is a little weird.
-He rented the house. -I know. That's why
I'm more like, no, I don't want him to be
banished from the house.
I'm...Yeah.
It's very hurtful. Why don't my friends see my side?
I'm going through
just as much as Brittany, if not even worse.
[crying]
Never.
Janet, you have been a sh--ty ass friend.
You are a ----ing vibe killer. You're exhausting.
You give Karen energy, and I'm ----ing done with it.
Daniel came in and then, like, chugged out of a tequila bottle.
-Mm-hmm. -I was in a relationship
for years where somebody had drug and alcohol problems.
Like, that's kind of, like, really a big thing to say,
like, if you have a problem with Daniel's like drinking.
-I was not drunk. -I feel like she wants
to stir the pot, and I'm like, but why?
See, that's what I'm...
Uh, Jax just wrote me. "The home is in foreclosure,
and you will be responsible."
[voice breaks] What in the world did I do to deserve any of this?
* I'm all right *
* I'm all right *
* Everything is all right *
* Everything is all right *
* I'm all right *
***
* Hold up *
[horn blares]
***
-* Wait a minute * -* Ah *
-Oh, my God. -We're actually doing this.
-Turn. Twist. -Yay! Look at this.
Look at us go. Do I have brakes on these?
I have--I think--no, you have the professional ones.
-Oh, my God. -Aah! Oh, my God. I'm scared.
-Just roll. -I'm rolling.
-Roll. -Rolling.
-Oh, please don't hit me. -Oh, sh--, I can't stop.
-Oh, my God. I can't stop. -[horn blares]
Aah! [bleep]
***
BRITTANY: I think he gets out on the 21st.
I hope Jax does get better in some way so that Cruz has
a good relationship with a better man.
BRITTANY: Right now, like, he's dead to me.
And I was, like, looking around the house to see if
I could find my wedding ring, and I don't know where it is.
Have you checked his eBay page recently?
He was selling my Jenny Craig bags!
-You're joking. -[laughter]
For, like, $30! I'm not kidding.
What is the resale value of that on eBay?
Apparently $30.
[laughter]
***
ZACK: What's up, bitches?
-KRISTEN: Hi. -Happy housewarming.
Thanks, honey.
Although we are just moving in,
Luke and I are gonna be hosting our little housewarming party.
Might as well ignore some of the mess
and enjoy this house a little bit.
-You're good. -Whatever was left in my bar...
Thank you so much. I love it.
...that I didn't want to drink for myself, so...
Do you wanna put it on the bar cart?
-Sure. -Hello!
Hi!
Hello, hello, hello!
Oh, my God. You didn't wear linen today.
I had linen pants on, but they were a little hot.
-[laughter] -Hey.
Oh, it looks so much better black.
-Right? -Yeah.
Caw-caw!
Did you bring a bathing suit?
Nobody told me anything about bathing suits.
Oh, well, Kristen sent out the invites.
Yeah. Great.
It's a peacock plant. I don't know why.
I don't know what a peacock plant is. I love it.
Me neither. But, you know, you have a plant, so...
-Amazing. -Housewarming party.
-Thank you, my angel. -This is really cute.
-I know. And it's private so... -I love it.
-...I love that. -LUKE: So, what's new, man?
Anything, uh, on the Michelle front?
I haven't talked to her at all. I mean...
Dude, that's probably for the best.
She's not coming tonight. They're out of town.
-Yeah, I heard that. -I'm not knocking. It's a party.
-I'm not knocking. -Yeah. Do you knock or what?
Hi!
-Hi. -Hi, baby.
How are you?
Thanks for having this house party.
-Are you kidding? -Of course.
Let me just say. [sighs]
Delicious? So good. So good.
Jenna and I have been friends since I moved to L.A.
***
[camera shutter clicking]
Of course, I met her through Scheana,
because Scheana's like Kevin Bacon.
[bell dings]
It's always one degree of Scheana Shay.
I'm so glad to see you. I miss you so much.
-And you. Oh, it's so fun. -Let's go have some fun.
-Did you do a spa day? -Oh, my gosh.
-Did you do a little Botox? -So, it wasn't Botox.
It was, uh...Scrotox.
-Scrotox? -Yes.
-Have you ever heard of Scrotox? -No.
Neither had I.
I don't know what's going on here.
So, it's Botox for your scrotum.
What?
And apparently, it, like, feels, like, really good during sex,
and it just looks aesthetically better.
[snickering]
You know how, like, balls, like, go up and down?
I just was like, you know what?
Let's just see what happens when they stay down.
I am not getting Scrotox.
-MAN: Three, two, one. -[exhales deeply]
-Good. -[blows raspberry]
That one hurt.
Do they?
I guess I wanted to see what it feels like to have old balls?
I don't know. [laughing]
[snorts]
Should I have brought you? Jesse, would you have done it?
-The whole point... -100%.
Mother----er! I thought none of you would do it.
But I'm the weirdest of the whole group, too.
Goddamnit.
See? No sight of salmonella. You see that?
See how perfect that is?
So, leave it to the gay guy to do the flowers? Yeah.
-Hi. How are you? -Good. How are you?
-Good. -Whoo.
This is so cute out here.
Kristen's over there talking to Nia.
-Okay. -And Luke's at the grill.
I'll wait.
DANNY: At this point, Jason and I are pretty cool.
I really value our friendship a lot.
So do I.
But I have some definite frustration with Janet
saying things to attack me and my character.
She likes to stir the pot. She likes drama.
She likes getting reactions out of people.
It's really just...malicious.
-So, how are you? -Good. How are you feeling?
-I feel like some, like-- -I feel great.
You sure? Okay.
At the beach, I've never seen Jason worked up like that.
She thinks we all talk sh-- about each other
because you're the only one doing it.
It's not sh--. I'm saying that was two years ago!
I can't believe that, like, the biggest snake
in the grass has been under my nose this whole time.
Okay, yes, I'm the biggest snake.
He's hurt because sh-- was said years ago, but, like,
I didn't bring this up, and I don't care.
-We don't believe it. Like... -Right.
I would never hurt him like that.
The last time I saw Janet and Jason was at the beach.
I wasn't happy. I felt like I was a little ganged up on.
Are you gonna talk to Jason if you get a chance?
Yeah.
But I've never really had an issue
with Janet and Jason like this, and I just wanna get over it.
Hey, I just have one thing to say.
If possible, I would love to have a conversation
with you two and Melissa when she's in town.
Two adults--four adults, if that's okay with you guys.
-Yep. That works for me. -I would love that.
Okay. Perfect. One step at a time.
Okay, good. All right, well, have a good night.
-Okay. -She can--
That was a much better situation.
That was--Yeah, that was a better approach.
-The first one was hot. -Oh, do a trick.
Oh, wow. High five. Cheers.
-Okay. -You guys got your hair did.
I've got salmon sperm put on our face.
Yeah, so you feel like you're glowing. Does it work?
And we all just look pretty. I did, actually.
-Okay. -Yeah.
Mm-hmm.
No...
You should.
JESSE: Is it about me or...
I mean, kind of. Yes/no. So, I dated Aaron.
Who's Aaron?
-Michelle's boyfriend. -Oh, that guy?
-How long ago was that? -Uh...well, we dated twice.
-Okay. -So, first time was, like...
five years ago?
And then maybe, like...
God, a year and a half ago, briefly.
Interesting.
I had heard that, like, a year and a half ago, they--
Michelle and him were together.
-Oh, wow. -I don't know.
I'm still putting the clues together,
but Michelle and I are not in a good spot right now.
-I'm sorry. -So, trying to figure it out.
Six months ago, Super Bowl Sunday,
Luke comes up to me and says, "Hey, I heard a story
that Michelle was seeing a guy while you guys were married.
She couldn't get ahold of him. She stopped by his house
and caught him with another girl."
Is Jenna the girl?
The whole reason I found out about them was, um...
friends of Jax ran into them at a bar in West Hollywood
before anybody knew that we were separated.
So, it was, like, a big, like, why is Jesse's wife
kissing a guy at a bar in West Hollywood?
I have always been convinced that Aaron is...the guy,
if not one of multiple guys
that Michelle cheated on me with.
So, this Jenna story starts to line up with my timeline.
When I saw you, I was like, all right, this is full circle.
-It's a small world, yeah. -I was like, what are the odds?
It's wild out here.
I need to, like, sit down with you and Nia...
-Yeah. -...to figure out this trip.
Because with this move, with everything, like,
-I feel so... -I can't imagine, dude.
...in over my head at the moment.
Yeah.
LUKE: Kristen's very difficult to surprise,
and I am setting up a trip to propose to her in Hawaii.
I just don't wanna [bleep] it up.
-I want her to be surprised. -I know. I know.
I want her to not see it coming.
Kristen is very good at uncovering the truth.
Whatever you want to do, I am there for it
because I care about you guys that much.
So, we just have to keep Detective Doute off the case.
Love you, bro.
All right, let's go out there.
Yeah. Yeah. Don't want anyone getting suspicious.
Suspicious of what?! We're not doing another Scrotox.
-We do have to go. -Oh, you guys have to go now?
-I told the babysitter 11. -Okay.
-10:46. -Are you leaving? Bye.
-Bye. -[coughs]
-Hold up. -What is happening?
-Get... -Are you okay?
You're gonna choke. Don't choke! Heimlich!
-[continues coughing] -Heimlich.
Did you literally just choke? Heimlich!
Are you okay?
[laughter]
Oh, I gotta tell you guys something.
Last night, Jax came home for the mail.
-Yeah. -You know that.
And he had, like, uncovered all the cameras again and stuff.
And then me and mom were, like, covering them back up.
And then he knew that I was gonna be FaceTiming with Jenny.
-He's going to the hospital. -What do you mean?
His blood pressure is, like, super high.
God. Even as mad and angry at him as I am,
I don't want anything to happen to him.
They asked the actual therapist who, like,
goes around places with him. -Yeah.
She said that he made the girl--
the girl who answers the phone--cry because
he told her if anybody calls, to lie and act like
he is on his way to urgent care, and she was sobbing, crying.
He made her, like, feel like she had to tell people that.
And so the therapist had to tell all of us the truth,
that he never went to the hospital.
He manipulated the front desk person...
-Yes. Yes. -...to say he was having
a medical emergency? -Yes.
I know for a fact Jax is putting out
a completely different story,
and he wants to sugarcoat everything
and make things look better than they are
whenever, really, I'm going through hell.
Also, he wrote me this, like, really long email,
and he's told me that the house is in foreclosure.
He could, like, actually ruin my chances
of ever buying another home or anything.
You wouldn't be able to get a mortgage again for sure if you--
Yeah. Because my name is on it just as much as his is.
And you would lose all the money in the house.
I would lose the money I put down,
the equity that we that we put in.
Does he not realize that that's, like, damaging to Cruz?
Oh, that's what I said. But he also said,
"We're splitting the podcast 50/50.
I'll do one week. You do the next."
That is so disappointing after what he was saying two days ago.
JAX: Brittany and I have a very successful podcast.
I talked to my manager,
and she just gets the full amount
until we pay off what needs to be paid off.
-If he doesn't fix this... -Lawyer, lawyer, lawyer.
...I'm ready to fight.
Coming up...
Kristen said, "Jasmine said that
you take your ring off when you go out."
Me and her never had a conversation about you guys.
***
-* I'm hot * -* Whoo *
* What you know about it? *
* I'm hot *
-* Whoo * -* What you know about it? *
* So fierce, so knock it on over *
-* So fierce, so... * -[doorbell rings]
[barking]
The highlight of your whole day.
[barking continues]
-Hi, you. -Hi. How are you?
I'm good. How are you?
-Good. -Do you want anything to drink?
I have flat water, sparkling water.
-Sparkling, if you have. -Yeah?
Yeah. Yeah, Isabella's-- she always asks questions.
I was driving her to school, and she's like,
"Mommy, why is Daddy's place bigger?"
I'm like, "All that matters is you have a roof over your head.
She's like, "You're right, Mommy."
Yeah. See, you're teaching her things.
This is, like, gonna be a well-rounded kid.
I have to, like, undo what he does.
I just constantly have to teach.
-It gets exhausting, right? -Yeah. She has his personality.
Yeah.
And I'm like, I'm not gonna have an entitled child.
Every day is just work.
That part, I would say is the hardest part
about co-parenting.
Because whatever Ocean wants to do, "I wanna go swimming now,"
they go swimming now.
Like, I know when she's been with him, 'cause we'll go
to Target, and she'll just throw things in the cart.
-Yeah, same. -And I'm like, no.
Does Jesse, like, do you see similarities
and the same patterns as your ex?
Yes. Yeah.
I didn't realize how, like, sometimes
he was so disrespectful to people,
and I always had to just, like, brush it off.
Well, I think you become desensitized.
I mean, my ex was not really kind to many people,
and I always thought it's 'cause he was insecure,
and it's like, no, he's an asshole.
-Yeah. -I cry every single day.
I feel like I've dealt with so much bullsh--
that it's, like, incredibly hard for me to cry.
Can I ask you a question?
'Cause there are times where I wanna ask you about your mom
and how she's doing, but-- -Yeah.
-Do you prefer we don't ask... -No, it's okay.
...and you can tell us when you want to share?
No, I actually don't talk about it a lot.
My mom got sick about a year ago
when I was going through everything with Jessie.
She thought she had food poisoning
and had to go to the doctor.
And she was diagnosed with stage IV colon cancer.
So, she did her first treatment of chemo, and it did not work.
So, then now she's in her second treatment.
But the problem is it's kind of everywhere now.
She's just like, by day... [sighs heavily]
[voice breaking] It's just killing her from the inside out.
I don't think I have much longer with her.
It's been very hard for me. [sniffles]
Because my mom is my best friend
and the one who supports me the most.
-I love you. -[chuckles]
I'm really sorry.
-[sighs] Thank you. [chuckles] -[chuckles]
Holy [bleep].
[both chuckle]
I feel like I just got hit by a bus.
[laughter]
[Michelle sighs]
* And I'm just going *
* Going through the motions *
* Sky so wide and open *
* My eternal getaway *
MELISSA: How are you?
-There's gonna be four of us? -JASMINE: Yeah.
-Okay. Come in. Welcome. -Thank you.
-All right. -Yeah.
I guess I'll sit here.
Oh, this is a cute little booth.
-I know. -We should go out more.
I know. [laughs]
A little nervous.
Yeah.
I hope this is peaceful.
I'll have a Tito's and ginger ale.
And I'll take a skinny spicy margarita.
-Thank you. -Thank you.
All right, my adrenaline is kicking in.
You wanna sit, or...
Hey.
-Hi. -Hi. How are you?
-Good seeing you again. -Hi. How are you guys?
-Hello. -How are you?
Jasmine's someone who I've had a friendship with
for more than eight years now at this point.
I really wanna look her in the eyes
and her look me in the eyes, and, like, what's going on here?
This is weird. I feel like two weeks ago,
this would have been a super fun restaurant trip.
-Yeah. -I know.
Not 100% sure what happened, to be honest.
-Thank you. -Thank you.
Thanks so much.
We're both really pretty confused by a lot of stuff
that's happened over the last few weeks.
When we first learned about stuff,
it was at Brittany's pool party.
Um, Kristen came over and said, "Jasmine said that you take
your ring off when you go out" or something like that.
And when I first heard it, it was such, like,
an out of left field, like, jarring comment that I'm like,
that doesn't make any sense. I don't take my ring off.
Then I was kind of like, wait, I don't really understand this.
Like, why was this said? Why did Jasmine say this?
And, like, why would she tell Kristen, who, like,
was not in a good place at all with Janet?
Is there anything that I've said so far that is inaccurate?
Some...yes, because I never told Kristen.
I never talked about this. I never repeated it.
At the party,
I could have sworn that you said that you did, that--
Well, first of all, Kristen did say that you told her.
I heard this, like, two years ago.
-And you said that to Kristen? -Yes.
Me and her never had a conversation about
you guys and a ring or nothing. -Ever. They--this is--
She came to us and said, "Jasmine said this."
And then we're like, okay. And that's why I was like,
Jasmine's my friend. Call her in this conversation.
We never talked about any of that.
-Okay. But--okay. -But she is--she did blame you.
At the end of the day,
this conversation is not focused on he said this.
We're here to squash things with you guys because...
-Totally. -Yeah.
...I promise you, wherever the rumor started from,
it was not us who originated it. -Swear to you guys. Swear.
I appreciate that, and I trust and believe you guys truly.
I know you guys are good people.
There is another part that's really still bugging me...
-MELISSA AND JASMINE: Yeah. -...is at the beach...
-Oh. -...it seemed like you had,
like, some really deep-seated resentment toward Janet.
Um, I will say, like, at that time, that's how I felt.
But, like, I don't think you're a Karen or anything like that.
-Isn't your mom named Karen? -Yes, Karen Denise Goode.
She goes by Denise because she hates it.
Also, I looked up the definition of Karen.
It was, like, entitled something.
I was like, all right, I might be a little guilty of that.
I think we all have a little Karen.
-[laughs] -I will apologize about that.
-I appreciate that. -I think it was just more
in that moment, I think it was just how I was feeling.
And then, like, being alone. My brain is, like,
I was just so, like, heated. -JASON: This makes sense to me.
Like, how do they think I can do this? You know, I'm like--
If I would have known at all that you felt like
it's two against one, I would have been like,
"You guys talk." Like, that was never--
-I'm--I'm really sorry. -Actually, I'm honestly
kind of happy hearing how you guys are talking about this.
You're coming from the same place where we are,
where we're also like, what happened to...
-Yeah. Yeah. -...make us think
that we're all against each other?
I've had a long history of friendship with Jasmine,
and what I'm starting to see
is Jasmine's not the mastermind here.
It feels like she is just a mouth
for the actual mastermind, which is Kristen.
-Can we hug it out? -Yes, of course.
-I love you, Jason. -Love you, too.
You know I love you.
I wanna be good with Janet because I feel like
nobody wants to be on Janet's bad side,
because it could be scary. -[music warps down]
And I love them. They're, like, one of my closest friends.
-All right, I love you guys. -Should we just assume
that it was a miscommunication from the start?
-Yes. -I love you, too.
-I love you. -You know I love you guys.
JANET: Do we get to stay and eat?
[laughter]
Coming up...
-Is he stalking you? -He was looking at me
through the cameras and stuff, and then he was, like,
telling me what I was wearing and different things.
-Oh, that's concerning. -Yeah.
***
[roaring]
***
I'm pretty excited to walk out that door.
I have anxiety. I'm anxious. I'm scared.
But you know what? It's time.
I know I have a lot of apologizing to do,
um, but I just hope that they can see that,
you know what? He's making the progress.
He's taking the steps. He's trying.
[doorbell rings]
[gasps] It's here!
[dog barking]
Sissy, relax. Oh, my God. [laughs]
Oh, my God. Okay.
***
* I never felt so good *
Hola.
-* I never felt so... * -Hello!
Hi!
ZACK: Is an army coming over? I'm confused.
My girlfriends and Zack are coming over today
to help me pack up all of Jax's sh-- because I don't
want him to have excuses to keep coming over.
He's got his new little condo now.
-This is amazing! -[Brittany laughs]
I just need him to be gone.
Whoa!
[laughs]
MICHELLE: Anything for me to eat?
Brittany and I certainly have different taste buds.
She loves fast food.
Mmm. Yes.
-And I... -[music warps down]
...do not like it.
-Hi, hi, hi! -Oh, my God. So hot.
Hi. I'm starving.
So, if anybody says "Jax,"
you're taking a shot.
-I love it. [laughs] -'Kay?
[laughter]
Since he does get out on Thursday,
and today's Tuesday,
how about, um, Wednesday we take you out for, like,
uh, like, a last night before he's out of rehab?
And, like, like, let's just go to Jax's before than he--
-One last night, though. -Oh, you need to take a shot.
Hey! [laughs]
I'm-a get a chaser for this.
I had had this idea for literally months now
to change the name of Jax's bar to Britt's.
And then we'll just transform it for one night before...
sh--head gets out. -Yeah.
We want Brittany to know that we support her,
we love her, and we're in this together.
How do you feel about seeing him?
I think it will, like, break me, honestly.
-ZACK: I know. -NIA: You need someone with you.
Like, you guys know that I, like, really actually love him.
He can, like, bring me back in a lot of the times,
but I feel like I'm being, like, so strong, and I'm like...
-ZACK: You are. -I can't do that.
-NIA: We're gonna support you. -Yeah.
I wish that I was getting the same support
that Brittany is getting.
I just think you're doing the right thing protecting Cruz.
You've done a really, really good job of it.
I am an amazing friend,
and I will drop anything and everything
if one of my friends need help, or they need something.
I am a ride-or-die kind of person,
and so I don't feel that in return.
***
We have not even went upstairs yet.
Let's go. Let's get to work.
All right, let's do this. Oh, my God.
Wait, do you want boxes, or do you want bags?
Hey. Bags. I really don't give a sh--.
* Hey, hey, you *
[laughs]
* Hey, hey, you *
-One shoe. -One shoe?
Yeah. One shoe.
-Separate them. -Yeah.
He can find a shoe in another bag.
Yeah.
Separating his shoes,
it's like a way to get Jax's brain working.
It's like how you work with little toddlers,
and you're like, "Okay, match this with this."
Let's be real. Cruz is more of a man than Jax is these days.
* Hey, hey, you *
-Aw. -No, no "aw"ing.
-* Hey, hey, you * -This is too funny.
-We're packing for him. -Loser!
Aw, his little jean jacket that he wears all the time.
-[Brittany sniffling] -Shut up.
What?
-You can say it out loud. -Hug her. Hug her.
Aw. Stop. It's okay.
You don't have to do this right now
if you don't want to, if it's too much, you know?
You can go back downstairs and just chill.
This is really, really hard. I still love this guy.
Do you want us to do it, and you go downstairs?
No, I'm fine. I'll be okay.
Like, those feelings aren't gonna just disappear overnight.
I don't think this is valid anymore.
-Aw. -Don't do that. Just throw it.
-Just throw it in there. -No, it's fine. Aw.
He's the father of my child.
We've been together for 10 years.
Like, I have built a life with him,
and I never in a million years thought that I would be here.
I never thought that we would even separate.
I love you so much.
Will you please be my wife?
[crying] Yes.
As much as it pains me, what's actually
making me stay strong in all of this is Cruz, my son.
Like, me, being happy
is gonna be so much better for him in the long run.
Everybody grab a bag.
I feel like a naughty Santa Claus right now, guys.
Get through the door.
Like, we're--we're scolding a bad child and only
making sure he has coal. -All right.
-And last... -[music warps down]
...bag.
Zack, is this something you do with your wiener?
No, I don't put my wiener in things that are warm.
What? No, that's for eyeglasses.
[laughter]
Coming up...
-Let's go for a walk. -We have nothing to hide.
-[laughs] -Let's go for a walk.
-That's one. -That's crazy.
-* I feel breathless * -[horn blares]
* When you are running *
* Restless when you're still *
-Hello. -Hello.
Hi. My name is Brittany Cartwright.
-I have an appointment. -Yes. Follow me.
Thank you. Okay.
You can sit here.
All righty. Thank you so much.
-Hello. Hi. -Hi, Brittany. I'm Naz.
-Nice to meet you. Welcome. -Brittany. Nice to meet you.
With Jax getting out of the facility soon,
I'm meeting with a lawyer to try to figure out what she thinks
about the situation, tell her everything that's going on.
All my friends have been begging me
to go see a lawyer for months now,
and I think it's the right time, before he gets out.
So, tell me what's going on.
Well, I have been married since 2019.
We separated in January of this year.
Okay.
We didn't, like, legally separate, though.
We just kind of, like, I moved into an Airbnb for a while,
and we just continue fighting.
Nothing's getting better. So, I was just wondering,
you know, what I should do to protect myself.
What led you to my office today?
Um, his blowups just getting more and more aggressive.
Like, he's, like, thrown furniture
and, like, punched walls and stuff, but he hasn't, like,
laid his hands on me. -Oh, wow.
-Yeah. -Okay. Okay.
Really bad. Yeah.
-You need help. -You need help!
I have to go to therapy because of all the stuff
you've done to me! I don't understand--
If you were that miserable, you could have left years ago.
He is in rehab right now, so he doesn't--
-Okay. -He gets out tomorrow.
He still has been like, rage-texting me.
Like, this just was the other night before.
I had to block him.
Like, you can just, like, tell how he talks to me.
He's so worried about me being with guys.
How does he know you're not home?
-Exactly. -Is he stalking you?
He was looking at me through the cameras and stuff.
And then he was, like, telling me what I was wearing
and different things. -Oh, that's concerning
-Yeah. -...and disturbing.
-I don't like that. -Yes. Yeah.
-This is a lot of text messages. -Yeah.
-He's obsessed. -Yeah, he is obsessed.
-It's not healthy for you. -Yeah.
And he really needs to control himself. This is not good.
I know.
Um, you do have a child together?
Yeah. We have a son together, and we own a home together.
-Okay. -He stopped paying our mortgage
whenever I moved out, and I didn't know that.
Did you have any conversations before you moved out in January
about who was gonna pay what and how much and for how long?
So, he's always paid the mortgage,
and I've always paid all the bills.
He was so far behind on his taxes before we got married.
Like, I think it was, like, $1.2 million
behind or something crazy. -Oh, wow.
He was gonna go to jail if I didn't, like, allow him
to put it on our house, if that makes sense.
-Oh, my goodness. Okay. -Yeah.
So, our mortgage went from, like, $8,000 to--
it's at, like, $17,000 right now because of--
-Because of his arrears? -Because of his stuff.
Oh, wow.
And they even went into my bank account
and took $100,000 out of my bank account
just 'cause I was married to him.
-Oh, my. -Yeah.
That's not okay.
He got a lease at a condo without telling me as well.
And now moving forward, he wants me to take
over the house, like, completely.
And at that point, you're gonna start paying the mortgage
all on your own. Okay. -Yep.
Uh, and continue to pay all the other expenses
you've been paying? -Mm-hmm.
So, what will his contribution be financially?
-That's why I need help. -I see.
Because I literally pay for everything for my son.
Never asked him to pay anything because he was
taking care of the mortgage this whole time, I thought.
Yeah, he definitely has a problem,
and this is, uh, not normal.
I'm kind of, like, scared right now.
Um, I do think filing for divorce, the sooner the better.
Just, I think, because it will let him understand
that this marriage is over.
Yeah. Yeah.
I didn't come into this meeting thinking
I was going to file for divorce, but this is making me realize,
like, wow, this is bad, and I need to get out of this.
I recommend you be the first one filing.
-You be the petitioner. -Yeah.
If you can do so, that would be a tiny bit in your interest...
-Yes. -...I would say.
I think I need to be-- I'm scared.
Like, I-- he's so all over the place.
I never know what he's gonna throw at me.
I mean, could I start the filing process today?
I can prepare the petition today,
and I can go ahead and file today or first thing tomorrow.
I'm just so terrified that I'm gonna allow him
to slowly make his way back into my life.
So, I really need to, like, go ahead and rip the Band-Aid off,
get this process started, and never look back.
Go for it.
-Oh, my gosh. -Let's do this.
Oh, this is crazy.
I just know deep down that this is the right next step to do.
I can't believe I haven't cried. This is crazy.
You know why? Because you're ready.
Yeah.
Those who are not ready are the ones that typically cry.
-Yeah. -I think you've had a good
seven, eight months to process all this.
-Yeah. -And I think having gone
through all the ugly stuff you've gone through, it's like,
you know this is what you want. -Yeah. I'm kind of feeling
a little relief, which is weird. -Good. That's--no, that's also
a sign that you're ready. -Yeah.
You're done.
***
Coming up...
Welcome to your bar, my love.
Wait, what have you guys done?
ALL: Welcome to Britt's!
***
* All working together *
* All working together *
***
It's perfect.
***
Yay!
-ZACK: Finally. -NIA: Are you excited?
-[grunts] -[squeals] Great day.
-I'm so excited. -Look how pretty this looks.
This is incredible. I saw the ladder out.
Do we need to, like, get that sign up quick? Like, what's...
Oh, yeah, let's get that sign up, because if she doesn't--
I don't want her to come and see that.
Right. We have a little bit of time for her,
but not, like, anybody else. -Exactly.
My vision for Britt's bar takeover
is to erase Jax from this bar.
-Yeah. Should we put them on? -Yeah.
Every picture.
I have, like, pictures of her to put in the frames. Yeah.
-That's a hot picture, though. -It's a great picture.
Every essence of Jax that I can find.
Guys, this is like--I'm... I like it.
And if someone wants to say...
[mockingly] "Oh, he's in a mental health facility.
He's so fra--" [normal voice] He's not fragile.
Be very safe.
If I die doing this, I swear to God...
Brittany will know how much you love her.
What I'm willing to go for friendship.
Jesus Christ. [sighs]
-Does that look like Britt's? -It--It looks good.
-Let's keep it moving. -JANET: Oh, my God.
-That's wild. -Oh, my God.
We tried. It's not perfect, but we tried.
I mean, I'm impressed. You guys just did this.
Oh, my... [laughs] God.
All the pictures of, like, Jax are down.
It's all pictures of Brittany now.
This is smart.
I love it. It's gonna piss him off,
which I love even more.
Welcome to Britt's.
JESSE: I'm sure this is gonna go over well.
-Oh! -Love it.
Oh, I love it.
[laughs] So...
Yeah, that's kind of where I am on that.
I think it's gonna be the opposite.
Jason thinking Jax might think this is funny
is probably like me thinking Michelle would think
it was funny that I called her an escort.
Well, she's a hooker, so it's fine.
I'm the mother of your ----ing child!
Unfortunately, that didn't resonate well. [chuckles]
JESSE: When is Brittany getting here?
Um, 10, 15 minutes. She's always a little late.
Okay, So I don't wanna, like, talk about it too much since
we're gonna have an amazing, fun night, but I'm very proud
of you for going to see the divorce lawyer today.
Mm-hmm. I filed.
You did?
[chuckles] I know.
[laughs] Thank you.
-You always smell good. -Yeah. I filed.
I don't-- I'm so ----ing proud of you.
I started kind of feeling guilty afterwards.
I was like, oh, my God, is it bad that, like,
I'm filing the day before he leaves rehab?
That's on him, though. He had many, many, many years...
-Yeah. -...to go to therapy on his own.
-Mm-hmm. -...to try anything,
the bare minimum. -Yeah.
-And he didn't. -Well, let's not tell everybody.
Like, obviously don't say anything.
Oh, sh--. Okay. Kristen said they're almost here.
Come on. Let's all go by the back.
What? Here?
Yep, we're gonna go all by the back,
and we're gonna, like, plug in the sign.
[Brittany speaks indistinctly]
The car just pulled up. They're getting out of the car.
What is today? Oh, it's a Wednesday.
[laughs]
What? Shut the [bleep] up.
Shut up! Wait.
-Welcome to your bar, my love. -Wait, what have you guys done?
-[squeals and laughs] -Whoo!
-[laughs] Oh, my God. -[laughs]
Oh, my God. Shut up. Oh!
ALL: Welcome to Britt's!
[cheering]
[laughs]
That is hilarious!
[laughter]
What the hell? Oh, my God.
-Welcome to Britt's. -[laughs]
-Yay, it's Britt's. -You all have the shirts on?
-Number one girl in the group! -Oh, my God.
This was, like, the sweetest thing ever.
All my friends know how much I've been going through
and actually how much work I put into this bar,
so to see that they changed it to Britt's and, like,
did all of this for me just to make me have
a good night before Jax gets out tomorrow is so--
I think it's just amazing. Like, I've got the best friends.
I love you. Did you do all this?
-Of course. -[laughs]
We just wanted to make sure that you had,
like, a really special night
before somebody gets out of somewhere
and comes back, because we just love you so much.
Thank you! That was so sweet.
I love you guys. Thank you so much.
-I love it. -This is so awesome.
-Let's have fun. -And we also wanna take you
through the rest of the bar because there's more fun stuff.
BRITTANY: Oh, my God. Jax is gonna die.
I get that. I was actually just thinking that when I saw this.
I was like, are you feeling like you didn't get the same...
Yeah.
I'm literally going through the same exact thing,
if not worse.
Like, where is my support?
Can we join you guys?
Hi. Yeah, yeah, yeah. Get over here.
Just really hurts my feelings
to go through something so tragic like a divorce
and a sick mother.
This is the time that I really need my girls.
-To Brittany and Britt's bar! -You guys!
[laughs]
-Cheers. -Cheers!
Hello!
***
Chilled straight from the bottle.
[indistinct conversations]
JESSE: It's clear that Danny hides his drinking from Nia
because it upsets her when he drinks. Tonight's the night.
There is a 99% success rate that Darkside's coming out.
Can I do a Jameson and ginger ale with, uh, lime?
[indistinct conversations]
Doing a little?
Whoo!
-No! -Hey, Kristen, uh...
I want you to help fill Kristen in.
-I just wanna ask-- -We kind of started talking.
Is there anything else, like, that you have
resentment or is there anything I'm unaware of?
I just wanna make sure we're, like, solid and good.
I met with Janet to squash things
after the whole ring rumor,
and I thought that Janet and I were good.
I thought we were on the same page.
Let's join our powers for good.
Let's get Britney out of this sh-- situation.
But now I'm hearing from Scheana
that Janet has not let this ring thing go
and is now talking sh-- about me again.
All this stuff happened kind of recently.
I think we're moving toward a good trajectory.
So, if we wanna clear the air,
you called Scheana immediately or text her, I'm not sure,
and said shady ass sh--. Then I'm like, well, what are
you saying about me when I'm not around?
Like, that's where my brain's at.
-I saw her later that day. -That's what she said.
Like, we already had plans, but we did talk.
Has Kristen Doute ever apologized
for anything in her ----ing life? No.
She's sorry that she got caught. Girl came after my husband.
Good luck. You just put a target on your back, bitch.
And I did say, like, "How sure are you--"
But we literally just had a lunch,
and then you immediately run to Scheana.
Like, why are you just talking about other things?
That's the story with Scheana. That's the whole game
with telephone that sucks in this group.
-Right. -Yeah.
I'd rather you not talk about other people, though.
You know, last summer, I heard a lot
about Janet scheming and manipulating.
But, you know, I never really noticed too much of it
because it wasn't towards me.
-I'm pissed about it. -I very much agree with you.
-Very, very much. -And so I'm gonna call sh-- out.
But now I'm definitely starting to see
what people are talking about.
I'm not the only one guilty of, like,
talking about other things 'cause it's all woven...
No. No, no, no, no, no.
-That's what I'm saying. -Listen, and I hear you guys
say that you guys are good with Jasmine?
No, I didn't say we're not good.
NIA: She said, "We're good." Daniel.
I did not say that. I said we are good. We talked.
-You talked? Yeah. Yeah. -Yeah, we talked.
We're good in that situation. What else do we--
You're good in that situation about the ring?
-Yeah, we're good. -And we're not good
about other stuff? -No.
It's like a couple drinks, and all of a sudden a shot in,
it's like goes from being, like, buzzed Danny
to Darkside Danny.
Daniel, you can't speak for someone else.
Because you have brought things up
and used Jasmine's name and said Jasmine said this
and Jasmine said that. -Yeah, we talked about that.
-Right? -We talked about that.
I mean, I'm not stopping him. He's not stopping his mouth.
-So, whatever. -Yeah.
-Luke... -I can't control him.
...I'm going with Nia to the bar.
It's very clear what's happening.
Danny is wasted,
jumping in a conversation he would never jump in soberly.
I mean, Nia can't even drag him out.
Obviously, this is Darkside Danny at his finest.
Danny, just relax for a bit 'cause this is not gonna go...
-Wow. -...how you think it's gonna go.
It's not my job to tell him it's okay.
Drop this right now, and we're good.
I don't know what's going on with you right now, but it's...
-Where's Nia? -What did you just say?
What do you call him, Darkside Danny, whatever it is?
You're being ----ing weird right now. Just relax.
Whatever.
***
JASON: You're being ----ing weird right now.
Just relax.
-Let's go for a walk. -Take him.
-Take him outta here, Jesse. -Let's go for a walk.
-Wow. -It's not gonna be wow for him.
Not "wow," dude. "Wow" to you. You're the "wow" guy.
JANET: We have nothing to hide.
-[laughs] -Let's go for a walk.
-That's funny. That's funny. -That's crazy.
My husband's not the one out here grabbing asses.
Classic Janet, pointing fingers at everyone else.
We just talked about you talking about other people,
and you go firing stray bullets at Danny again.
You don't get the point, Janet. Stop talking about other people.
-And I was like, I didn't... -No, we literally...
Good. 'Cause look what happened.
Yes...
Well, they protect each other as a couple.
Really quick, the only thing--
I am frustrated
with Daniel that, like, he kept poking at Janet.
I'm not participating in that.
But also it's kind of like, who do you think you are?
Why are you coming at my husband?
You're supposed to be our friends,
and I just don't get it.
I don't know why she needs
to continue to come at Daniel or us.
He's definitely the biggest lightweight
in the group, male or female. -Yes, I have spoken about
the things he did in this bar, but so has everybody else.
Look at Janet just going in right now.
What happened? You know, just Janet's, like,
coming in Daniel's face, and I just don't have time for that.
She lies. She just lies and tries to stir the pot.
We need to go because the Uber's here.
But again, it's her that's trying to bring something up
out of nothing. -Got it.
-Hasta luego. -Okay, good night.
You have my phone?
***
I'm not the ass grabber.
He's mad at himself, but he's misplacing the anger on me.
-Yeah. Yeah. -That's what's happening.
And he's heard information from other people about you
that is false. -He's mad at himself because
he is a drinking problem, and he comes to this bar
and does stuff that he's embarrassed by,
and he's blaming me for talking about it
instead of being mad at himself for what he has done.
I'm not making up things that he did. I'm not lying.
Maybe it's not my place,
but I've been showing Danny a mirror of the truth.
You did this.
-Cheers. Love you. -Cheers.
-We're still good. -I know. Yes. I'm like...
I understand. I understand everything that just happened.
-Yeah, yeah. -Are you not drinking tonight?
-No. -Good for you.
I got--I wanna be a little clear-headed for tomorrow.
Yeah.
I'm picking Jax up at rehab tomorrow.
I wanna pick you up. Let me know the details.
Send me the address, and I will, uh, I will be there.
The ----ing night before,
we are changing the name of his bar that he's in love with,
covering his name and putting Britt's name over it.
Fan ----ing-tastic.
Jax was very specific about including Brittany
in the entire process.
-JAX: Okay. -TVs here and here.
-TVs, okay. -Wallpaper has to go.
Wallpaper. Leave that to you.
Oh, it looks so good! Oh. [sighs]
Wow. We have a bar in the Valley.
-[laughs] -The only way I'm gonna do this
is if my wife's involved.
[cheering]
There's a clear divide now. I think it's super sad,
and here we are,
trying to get him to regress the second he gets out.
What is the plan for his stuff?
Yesterday all the girls came over,
and we packed up everything.
I don't want him to come out, see his sh-- packed up,
hear from somebody that, you know,
there's shirts floating around saying "Britt's"
and go on the attack, you know, start attacking.
-I told the guys that-- -If he does that,
then it's just proof that he's never gonna change.
When it comes to me and Jax right now, like,
I...I got him by his balls.
'Cause I could do worse if I wanted to,
and I could do less if I wanted to.
-Yeah. -So, like, he needs
to realize that and, like,
respect me for my decisions that I'm making.
How much winning do you have to do?
-You know what I mean? -He's not gonna win against me.
-I'm sorry. He's not. -I know. I know.
That's what I'm saying. Everybody's thinking that--
-There's no comparison. -We shall see.
T minus 12 hours and counting, people.
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.